@@ -1,8 +1,6 @@
 use utf8;
-use 5.008;
 package Text::Continuation::Parser;
-our $VERSION = '0.3_1'; # TRIAL
-$VERSION = eval $VERSION;
+our $VERSION = '0.1';
 use warnings;
 use strict;
 use Carp qw(croak);
@@ -29,7 +27,7 @@ sub parse_line {
     chomp($new);
     $new =~ s/\r//g;
     if ($new =~ /^\s*#/) {
-        if (length($line//'')) {
+        if (length($line)) {
             return parse_line($fh, $line);
         }
         return $new;
@@ -40,7 +38,7 @@ sub parse_line {
     elsif ($new =~ /\s+\\\s*$/) {
         $new =~ s#\s+\\\s*$##;
         $new =~ s/$trim//g;
-        if (length($line//'')) {
+        if (length($line)) {
             if (length($new)) {
                 return parse_line($fh, join(' ', $line, $new));
             }
@@ -51,7 +49,7 @@ sub parse_line {
     elsif ($new =~ /\S+\\\s*$/) {
         $new =~ s#\\\s*$##;
         $new =~ s/$trim//g;
-        if (length($line//'')) {
+        if (length($line)) {
             if (length($new)) {
                 return parse_line($fh, join('', $line, $new));
             }
@@ -61,22 +59,22 @@ sub parse_line {
     }
     elsif ($new =~ /^\s+/) {
         $new =~ s/$trim//g;
-        if (!length($new) && length($line//'')) {
+        if (!length($new) && length($line)) {
             croak
                 "Line continuation detected and empty line. This is invalid";
         }
-        if (length($line//'')) {
+        if (length($line)) {
             return length($new) ? join(' ', $line, $new) : $line;
         }
         return $new;
     }
     else {
         $new =~ s/$trim//g;
-        if (!length($new) && length($line//'')) {
+        if (!length($new) && length($line)) {
             croak
                 "Line continuation detected and empty line. This is invalid";
         }
-        return length($line//'') ? join('', $line, $new) : $new;
+        return length($line) ? join('', $line, $new) : $new;
     }
 }
 
@@ -94,7 +92,7 @@ Text::Continuation::Parser - Parse files with continuation lines
 
 =head1 VERSION
 
-version 0.3_1
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -144,17 +142,6 @@ Lines like these will make sure the function dies:
 While it may be possible in a shell, this is probably not what you intended and therefore
 F<parse_line> dies.
 
-=head2 CAVEATS
-
-On older Perl versions, like 5.10 you must do the following:
-
-    use FileHandle;
-    # or..
-    use IO::File;
-
-    open my $fh, '<', 'myfile';
-    parse_line($fh);
-
 =head1 AUTHOR
 
 Wesley Schwengle <waterkip@cpan.org>
